@@ -1,9 +1,9 @@
 package BorderStyleBase;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-31'; # DATE
+our $DATE = '2021-02-04'; # DATE
 our $DIST = 'BorderStyleBase'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
@@ -31,8 +31,10 @@ sub get_border_char {
 
     my $c = $bs_struct->{chars}[$y][$x];
     if (!defined($c)) {
-        if    ($y == 6) { $c = $bs_struct->{chars}[0][$x] }
-        elsif ($y == 7) { $c = $bs_struct->{chars}[5][$x] }
+        if    ($y == 4 && $x == 6) { $c = $bs_struct->{chars}[4][0]  }
+        elsif ($y == 4 && $x == 7) { $c = $bs_struct->{chars}[4][3]  }
+        elsif ($y == 6)            { $c = $bs_struct->{chars}[0][$x] }
+        elsif ($y == 7)            { $c = $bs_struct->{chars}[5][$x] }
     }
     return unless defined $c;
 
@@ -65,7 +67,7 @@ BorderStyleBase - A suitable base class for most BorderStyle::* modules
 
 =head1 VERSION
 
-This document describes version 0.007 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2021-01-31.
+This document describes version 0.008 of BorderStyleBase (from Perl distribution BorderStyleBase), released on 2021-02-04.
 
 =head1 DESCRIPTION
 
